@@ -17,19 +17,14 @@ Avocado application command line parsing.
 """
 
 import argparse
-
-from configparser import ConfigParser
-from configparser import NoOptionError
+from configparser import ConfigParser, NoOptionError
 from glob import glob
 
 from . import exit_codes
-from . import varianter
-from . import settings
-from .future.settings import settings as future_settings
 from .nrunner import Runnable
 from .output import LOG_UI
-from .resolver import ReferenceResolution
-from .resolver import ReferenceResolutionResult
+from .resolver import ReferenceResolution, ReferenceResolutionResult
+from .settings import ConfigFileNotFound, SettingsError, settings
 from .version import VERSION
 
 PROG = 'avocado'
@@ -64,9 +59,9 @@ class FileOrStdoutAction(argparse.Action):
         if values == '-':
             stdout_claimed_by = getattr(namespace, 'stdout_claimed_by', None)
             if stdout_claimed_by is not None:
-                msg = ('Options %s %s are trying to use stdout '
-                       'simultaneously' % (stdout_claimed_by,
-                                           option_string))
+                msg = ('Options %s %s are trying to use stdout simultaneously.'
+                       ' Please set at least one of them to a file to avoid '
+                       'conflicts' % (stdout_claimed_by, option_string))
                 raise argparse.ArgumentError(self, msg)
             else:
                 setattr(namespace, 'stdout_claimed_by', option_string)
@@ -94,28 +89,28 @@ class Parser:
 
         help_msg = ('Turn the paginator on/off. Useful when outputs are too'
                     'long. This will be a boolean soon.')
-        future_settings.register_option(section='core',
-                                        key='paginator',
-                                        help_msg=help_msg,
-                                        default='off',
-                                        choices=('on', 'off'),
-                                        parser=self.application,
-                                        long_arg='--paginator')
+        settings.register_option(section='core',
+                                 key='paginator',
+                                 help_msg=help_msg,
+                                 default='off',
+                                 choices=('on', 'off'),
+                                 parser=self.application,
+                                 long_arg='--paginator')
 
         help_msg = ('Some commands can produce more information. This option '
                     'will enable the verbosity when applicable.')
-        future_settings.register_option(section='core',
-                                        key='verbose',
-                                        help_msg=help_msg,
-                                        default=False,
-                                        key_type=bool,
-                                        parser=self.application,
-                                        long_arg='--verbose',
-                                        short_arg='-V')
+        settings.register_option(section='core',
+                                 key='verbose',
+                                 help_msg=help_msg,
+                                 default=False,
+                                 key_type=bool,
+                                 parser=self.application,
+                                 long_arg='--verbose',
+                                 short_arg='-V')
 
-        future_settings.add_argparser_to_option(namespace='core.show',
-                                                parser=self.application,
-                                                long_arg='--show')
+        settings.add_argparser_to_option(namespace='core.show',
+                                         parser=self.application,
+                                         long_arg='--show')
 
     def start(self):
         """
@@ -128,7 +123,7 @@ class Parser:
 
         # Load settings from file, if user provides one
         if self.args.config is not None:
-            settings.settings.process_config_path(self.args.config)
+            settings.process_config_path(self.args.config)
 
         # Use parent parsing to avoid breaking the output of --help option
         self.application = ArgumentParser(prog=PROG,
@@ -150,10 +145,6 @@ class Parser:
         # option afterwards.
         self.subcommands.required = True
 
-        # Allow overriding default params by plugins
-        variants = varianter.Varianter(getattr(self.args, "variants.debug", False))
-        self.args.avocado_variants = variants
-
     def finish(self):
         """
         Finish the process of parsing arguments.
@@ -232,7 +223,7 @@ class HintParser:
         self.config = ConfigParser()
         config_paths = self.config.read(self.filename)
         if not config_paths:
-            raise settings.ConfigFileNotFound(self.filename)
+            raise ConfigFileNotFound(self.filename)
 
     def get_resolutions(self):
         """Return a list of resolutions based on the file definitions."""
@@ -253,9 +244,9 @@ class HintParser:
         """
         if kind not in self.config:
             msg = 'Section {} is not defined. Please check your hint file.'
-            raise settings.SettingsError(msg.format(kind))
+            raise SettingsError(msg.format(kind))
 
         uri = self._get_uri_from_section(kind)
         if uri is None:
             msg = "uri needs to be defined inside {}".format(kind)
-            raise settings.SettingsError(msg)
+            raise SettingsError(msg)
