@@ -17,22 +17,20 @@ Job Diff
 """
 
 from __future__ import absolute_import
+
 import argparse
 import json
 import os
 import subprocess
 import sys
 import tempfile
+from difflib import HtmlDiff, unified_diff
 
-from difflib import unified_diff, HtmlDiff
-
-from avocado.core import data_dir
-from avocado.core import exit_codes
-from avocado.core import jobdata
-from avocado.core import output
-from avocado.core.future.settings import settings
+from avocado.core import data_dir, exit_codes, jobdata, output
 from avocado.core.output import LOG_UI
 from avocado.core.plugin_interfaces import CLICmd
+from avocado.core.settings import settings
+from avocado.core.varianter import Varianter
 
 
 class Diff(CLICmd):
@@ -290,15 +288,13 @@ class Diff(CLICmd):
                     </table></td> </tr>
                     </table>"""
 
-                job_diff_html = html_diff.make_file((_.decode("utf-8")
-                                                     for _ in job1_results),
-                                                    (_.decode("utf-8")
-                                                     for _ in job2_results),
+                job_diff_html = html_diff.make_file((_ for _ in job1_results),
+                                                    (_ for _ in job2_results),
                                                     fromdesc=job1_id,
                                                     todesc=job2_id)
 
                 with open(html_file, 'w') as fp:
-                    fp.writelines(job_diff_html.encode("utf-8"))
+                    fp.writelines(job_diff_html)
                 LOG_UI.info(html_file)
 
             except IOError as exception:
@@ -390,9 +386,10 @@ class Diff(CLICmd):
     @staticmethod
     def _get_variants(resultsdir):
         results = []
-        variants = jobdata.retrieve_variants(resultsdir)
+        variants = Varianter.from_resultsdir(resultsdir)
         if variants is not None:
-            results.extend(variants.to_str(variants=2).splitlines())
+            for variant in variants:
+                results.extend(variant.to_str(variants=2).splitlines())
         else:
             results.append('Not found\n')
 
@@ -416,7 +413,13 @@ class Diff(CLICmd):
                 name_header = ['\n', '** %s **\n' % name]
                 sysinfo.extend(name_header)
                 with open(os.path.join(path, name), 'r') as sysinfo_file:
-                    sysinfo.extend(sysinfo_file.readlines())
+                    try:
+                        sysinfo.extend(sysinfo_file.readlines())
+                    except UnicodeDecodeError:
+                        msg = ("Ignoring file %s as it cannot be decoded."
+                               % name)
+                        LOG_UI.debug(msg)
+                        continue
 
         if sysinfo:
             del sysinfo[0]
