@@ -1,11 +1,14 @@
 #!/usr/bin/env python3
 
 import sys
+
 from avocado.core.job import Job
+from avocado.core.suite import TestSuite
 
 config = {'run.references': ['examples/tests/passtest.py:PassTest.test'],
-          'run.html_job_result': 'on',
+          'job.run.result.html.enabled': 'on',
           'run.open_browser': True}
 
-with Job(config) as j:
+suite = TestSuite.from_config(config)
+with Job(config, [suite]) as j:
     sys.exit(j.run())
