@@ -1,13 +1,11 @@
 import os
-import tempfile
 import unittest
 
 from avocado import VERSION
 from avocado.core import exit_codes
-from avocado.utils import process
-from avocado.utils import script
+from avocado.utils import process, script
 
-from .. import AVOCADO, BASEDIR, temp_dir_prefix
+from .. import AVOCADO, BASEDIR, TestCaseTmpDir
 
 SCRIPT_CONTENT = """#!/bin/sh
 echo "Avocado Version: $AVOCADO_VERSION"
@@ -26,11 +24,10 @@ test "$AVOCADO_VERSION" = "{version}" -a \
 """.format(version=VERSION)
 
 
-class EnvironmentVariablesTest(unittest.TestCase):
+class EnvironmentVariablesTest(TestCaseTmpDir):
 
     def setUp(self):
-        prefix = temp_dir_prefix(__name__, self, 'setUp')
-        self.tmpdir = tempfile.TemporaryDirectory(prefix=prefix)
+        super(EnvironmentVariablesTest, self).setUp()
         self.script = script.TemporaryScript(
             'version.sh',
             SCRIPT_CONTENT,
@@ -39,7 +36,7 @@ class EnvironmentVariablesTest(unittest.TestCase):
 
     def test_environment_vars(self):
         os.chdir(BASEDIR)
-        cmd_line = ('%s run --job-results-dir %s --sysinfo=on %s'
+        cmd_line = ('%s run --job-results-dir %s %s'
                     % (AVOCADO, self.tmpdir.name, self.script.path))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -48,8 +45,8 @@ class EnvironmentVariablesTest(unittest.TestCase):
                          (expected_rc, result))
 
     def tearDown(self):
+        super(EnvironmentVariablesTest, self).tearDown()
         self.script.remove()
-        self.tmpdir.cleanup()
 
 
 if __name__ == '__main__':
