@@ -9,12 +9,10 @@ from xml.dom import minidom
 from avocado.core import exit_codes
 from avocado.core.output import TermSupport
 from avocado.utils import genio
-from avocado.utils import process
-from avocado.utils import script
 from avocado.utils import path as utils_path
+from avocado.utils import process, script
 
-from .. import AVOCADO, BASEDIR, temp_dir_prefix
-
+from .. import AVOCADO, TestCaseTmpDir, skipUnlessPathExists
 
 # AVOCADO may contain more than a single command, as it can be
 # prefixed by the Python interpreter
@@ -22,7 +20,7 @@ AVOCADO_QUOTED = "', '".join(shlex.split(AVOCADO))
 PERL_TAP_PARSER_SNIPPET = """#!/bin/env perl
 use TAP::Parser;
 
-my $parser = TAP::Parser->new( { exec => ['%s', 'run', 'passtest.py', 'errortest.py', 'warntest.py', '--tap', '-', '--sysinfo', 'off', '--job-results-dir', '%%s'] } );
+my $parser = TAP::Parser->new( { exec => ['%s', 'run', 'passtest.py', 'errortest.py', 'warntest.py', '--tap', '-', '--disable-sysinfo', '--job-results-dir', '%%s'] } );
 
 while ( my $result = $parser->next ) {
         $result->is_unknown && die "Unknown line \\"" . $result->as_string . "\\" in the TAP output!\n";
@@ -36,7 +34,7 @@ $parser->plan eq '1..3' || die "Plan does not match what was expected!\n";
 PERL_TAP_PARSER_FAILFAST_SNIPPET = """#!/bin/env perl
 use TAP::Parser;
 
-my $parser = TAP::Parser->new( { exec => ['%s', 'run', 'failtest.py', 'errortest.py', 'warntest.py', '--tap', '-', '--failfast', 'on', '--sysinfo', 'off', '--job-results-dir', '%%s'] } );
+my $parser = TAP::Parser->new( { exec => ['%s', 'run', 'failtest.py', 'errortest.py', 'warntest.py', '--tap', '-', '--failfast', '--disable-sysinfo', '--job-results-dir', '%%s'] } );
 
 while ( my $result = $parser->next ) {
         $result->is_unknown && die "Unknown line \\"" . $result->as_string . "\\" in the TAP output!\n";
@@ -123,6 +121,46 @@ class OutputCheckOnOff(Test):
         process.run(cmd % ('stderr', '__STDERR_DO_RECORD_CONTENT__'))
 """
 
+OUTPUT_SHOW_TEST = """
+#!/usr/bin/env python3
+
+import sys
+
+from avocado import Test
+from avocado.core.job import Job
+from avocado.core.suite import TestSuite
+
+
+class PassTest(Test):
+    def test1(self):
+        config = {'core.show': ['none'],
+                  'run.references': ['/bin/true']}
+        suite = TestSuite.from_config(config)
+        with Job(config, [suite]) as j:
+            j.run()
+
+    def test2(self):
+        config = {'core.show': ['app'],
+                  'run.references': ['/bin/true']}
+        suite = TestSuite.from_config(config)
+        with Job(config, [suite]) as j:
+            j.run()
+
+    def test3(self):
+        config = {'core.show': ['none'],
+                  'run.references': ['/bin/true']}
+        suite = TestSuite.from_config(config)
+        with Job(config, [suite]) as j:
+            j.run()
+
+
+if __name__ == '__main__':
+    config = {'run.references': [__file__],
+              'core.show': ['app']}
+    suite = TestSuite.from_config(config)
+    with Job(config, [suite]) as j:
+        sys.exit(j.run())
+"""
 
 def perl_tap_parser_uncapable():
     return os.system("perl -e 'use TAP::Parser;'") != 0
@@ -136,17 +174,12 @@ def missing_binary(binary):
         return True
 
 
-class OutputTest(unittest.TestCase):
-
-    def setUp(self):
-        prefix = temp_dir_prefix(__name__, self, 'setUp')
-        self.tmpdir = tempfile.TemporaryDirectory(prefix=prefix)
-        os.chdir(BASEDIR)
+class OutputTest(TestCaseTmpDir):
 
     @unittest.skipIf(missing_binary('cc'),
                      "C compiler is required by the underlying doublefree.py test")
     def test_output_doublefree(self):
-        cmd_line = ('%s run --job-results-dir %s --sysinfo=off '
+        cmd_line = ('%s run --job-results-dir %s --disable-sysinfo '
                     'doublefree.py' % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -180,7 +213,7 @@ class OutputTest(unittest.TestCase):
         test = script.Script(os.path.join(self.tmpdir.name, "output_test.py"),
                              OUTPUT_TEST_CONTENT)
         test.save()
-        result = process.run("%s run --job-results-dir %s --sysinfo=off "
+        result = process.run("%s run --job-results-dir %s --disable-sysinfo "
                              "--json - -- %s" % (AVOCADO, self.tmpdir.name, test))
         res = json.loads(result.stdout_text)
         joblog = res["debuglog"]
@@ -205,7 +238,7 @@ class OutputTest(unittest.TestCase):
         # the correct fix is to run the entire test process with redirected
         # stdout and stderr, and *not* play with sys.stdout and sys.stderr.
         # But this change will come later
-        result = process.run("%s run --job-results-dir %s --sysinfo=off "
+        result = process.run("%s run --job-results-dir %s --disable-sysinfo "
                              "--output-check-record=combined "
                              "--json - -- %s" % (AVOCADO, self.tmpdir.name, test))
         res = json.loads(result.stdout_text)
@@ -230,7 +263,7 @@ class OutputTest(unittest.TestCase):
         with script.Script(os.path.join(self.tmpdir.name, "output_mode_none.py"),
                            OUTPUT_MODE_NONE_CONTENT,
                            script.READ_ONLY_MODE) as test:
-            command = ("%s run --job-results-dir %s --sysinfo=off "
+            command = ("%s run --job-results-dir %s --disable-sysinfo "
                        "--json - --output-check-record none -- %s") % (AVOCADO,
                                                                        self.tmpdir.name,
                                                                        test.path)
@@ -254,7 +287,7 @@ class OutputTest(unittest.TestCase):
         with script.Script(os.path.join(self.tmpdir.name, "test_check_on_off.py"),
                            OUTPUT_CHECK_ON_OFF_CONTENT,
                            script.READ_ONLY_MODE) as test:
-            command = ("%s run --job-results-dir %s --sysinfo=off "
+            command = ("%s run --job-results-dir %s --disable-sysinfo "
                        "--json - -- %s") % (AVOCADO, self.tmpdir.name, test.path)
             result = process.run(command)
             res = json.loads(result.stdout_text)
@@ -270,16 +303,27 @@ class OutputTest(unittest.TestCase):
                 self.assertEqual(stderr.read(),
                                  '__STDERR_CONTENT____STDERR_DO_RECORD_CONTENT__')
 
+    @skipUnlessPathExists('/bin/true')
+    def test_show(self):
+        """
+        Checks if `core.show` is respected in different configurations.
+        """
+        with script.Script(os.path.join(self.tmpdir.name, "test_show.py"),
+                           OUTPUT_SHOW_TEST, script.READ_ONLY_MODE) as test:
+            cmd = "%s run %s" % (AVOCADO, test.path)
+            result = process.run(cmd)
+            expected_job_id_number = 2
+            expected_bin_true_number = 1
+            job_id_number = result.stdout_text.count('JOB ID')
+            bin_true_number = result.stdout_text.count('/bin/true')
+            self.assertEqual(expected_job_id_number, job_id_number)
+            self.assertEqual(expected_bin_true_number, bin_true_number)
+
     def tearDown(self):
         self.tmpdir.cleanup()
 
 
-class OutputPluginTest(unittest.TestCase):
-
-    def setUp(self):
-        prefix = temp_dir_prefix(__name__, self, 'setUp')
-        self.tmpdir = tempfile.TemporaryDirectory(prefix=prefix)
-        os.chdir(BASEDIR)
+class OutputPluginTest(TestCaseTmpDir):
 
     def check_output_files(self, debug_log):
         base_dir = os.path.dirname(debug_log)
@@ -302,24 +346,23 @@ class OutputPluginTest(unittest.TestCase):
         self.assertIn("\n# debug.log of ", tap)
 
     def test_output_incompatible_setup(self):
-        cmd_line = ('%s run --job-results-dir %s --sysinfo=off '
+        cmd_line = ('%s run --job-results-dir %s --disable-sysinfo '
                     '--xunit - --json - passtest.py' % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_FAIL
         self.assertEqual(result.exit_status, expected_rc,
                          "Avocado did not return rc %d:\n%s" %
                          (expected_rc, result))
-        error_regex = re.compile(r'avocado run: error: argument ((--json)|'
-                                 '(--xunit)): Options ((--xunit --json)|'
+        error_regex = re.compile(r'.*Options ((--xunit --json)|'
                                  '(--json --xunit)) are trying to use stdout '
-                                 'simultaneously\n')
+                                 'simultaneously.')
         self.assertIsNotNone(error_regex.match(result.stderr_text),
                              "Missing error message from output:\n%s" %
                              result.stderr)
 
     def test_output_compatible_setup(self):
         tmpfile = tempfile.mktemp(dir=self.tmpdir.name)
-        cmd_line = ('%s run --job-results-dir %s --sysinfo=off '
+        cmd_line = ('%s run --job-results-dir %s --disable-sysinfo '
                     '--journal --xunit %s --json - passtest.py' %
                     (AVOCADO, self.tmpdir.name, tmpfile))
         result = process.run(cmd_line, ignore_status=True)
@@ -333,7 +376,7 @@ class OutputPluginTest(unittest.TestCase):
 
     def test_output_compatible_setup_2(self):
         tmpfile = tempfile.mktemp(dir=self.tmpdir.name)
-        cmd_line = ('%s run --job-results-dir %s --sysinfo=off '
+        cmd_line = ('%s run --job-results-dir %s --disable-sysinfo '
                     '--xunit - --json %s --tap-include-logs passtest.py'
                     % (AVOCADO, self.tmpdir.name, tmpfile))
         result = process.run(cmd_line, ignore_status=True)
@@ -353,7 +396,7 @@ class OutputPluginTest(unittest.TestCase):
         tmpfile2 = tempfile.mktemp(dir=self.tmpdir.name)
         # Verify --show=none can be supplied as app argument
         cmd_line = ('%s --show=none run --job-results-dir %s '
-                    '--sysinfo=off --xunit %s --json %s --tap-include-logs '
+                    '--disable-sysinfo --xunit %s --json %s --tap-include-logs '
                     'passtest.py' % (AVOCADO, self.tmpdir.name, tmpfile, tmpfile2))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -372,7 +415,7 @@ class OutputPluginTest(unittest.TestCase):
     def test_nonprintable_chars(self):
         cmd_line = ("%s run --external-runner /bin/ls "
                     "'NON_EXISTING_FILE_WITH_NONPRINTABLE_CHARS_IN_HERE\x1b' "
-                    "--job-results-dir %s --sysinfo=off --tap-include-logs"
+                    "--job-results-dir %s --disable-sysinfo --tap-include-logs"
                     % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         output = result.stdout_text + result.stderr_text
@@ -390,7 +433,7 @@ class OutputPluginTest(unittest.TestCase):
         self.check_output_files(debug_log)
 
     def test_show_test(self):
-        cmd_line = ('%s --show=test run --job-results-dir %s --sysinfo=off '
+        cmd_line = ('%s --show=test run --job-results-dir %s --disable-sysinfo '
                     'passtest.py' % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -407,7 +450,7 @@ class OutputPluginTest(unittest.TestCase):
     def test_silent_trumps_test(self):
         # Also verify --show=none can be supplied as run option
         cmd_line = ('%s --show=test --show=none run --job-results-dir %s '
-                    '--sysinfo=off passtest.py'
+                    '--disable-sysinfo passtest.py'
                     % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -417,7 +460,7 @@ class OutputPluginTest(unittest.TestCase):
         self.assertEqual(result.stdout, b"")
 
     def test_default_enabled_plugins(self):
-        cmd_line = ('%s run --job-results-dir %s --sysinfo=off '
+        cmd_line = ('%s run --job-results-dir %s --disable-sysinfo '
                     '--tap-include-logs passtest.py'
                     % (AVOCADO, self.tmpdir.name))
         result = process.run(cmd_line, ignore_status=True)
@@ -443,7 +486,7 @@ class OutputPluginTest(unittest.TestCase):
                    % os.path.relpath(self.tmpdir.name, "."))
         script.Script(config, content).save()
         cmd_line = ('%s --config %s --show all run '
-                    '--job-results-dir %s --sysinfo=off whiteboard.py '
+                    '--job-results-dir %s --disable-sysinfo whiteboard.py '
                     '--json %s' % (AVOCADO, config, self.tmpdir.name, tmpfile))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -461,7 +504,7 @@ class OutputPluginTest(unittest.TestCase):
     def test_gendata(self):
         tmpfile = tempfile.mktemp(dir=self.tmpdir.name)
         cmd_line = ("%s run --job-results-dir %s "
-                    "--sysinfo=off gendata.py --json %s" %
+                    "--disable-sysinfo gendata.py --json %s" %
                     (AVOCADO, self.tmpdir.name, tmpfile))
         result = process.run(cmd_line, ignore_status=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -485,7 +528,7 @@ class OutputPluginTest(unittest.TestCase):
     def test_redirect_output(self):
         redirected_output_path = tempfile.mktemp(dir=self.tmpdir.name)
         cmd_line = ('%s run --job-results-dir %s '
-                    '--sysinfo=off passtest.py > %s'
+                    '--disable-sysinfo passtest.py > %s'
                     % (AVOCADO, self.tmpdir.name, redirected_output_path))
         result = process.run(cmd_line, ignore_status=True, shell=True)
         expected_rc = exit_codes.AVOCADO_ALL_OK
@@ -562,9 +605,6 @@ class OutputPluginTest(unittest.TestCase):
         # Check that plugins do not produce errors
         self.assertNotIn(b"Error running method ", result.stderr)
 
-    def tearDown(self):
-        self.tmpdir.cleanup()
-
 
 if __name__ == '__main__':
     unittest.main()
